@@ -68,14 +68,14 @@ void ApptSummaryWidget::configUpdated()
 {
     KConfig config(QStringLiteral("kcmapptsummaryrc"));
 
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
     mDaysAhead = group.readEntry("DaysToShow", 7);
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
     mShowBirthdaysFromCal = group.readEntry("BirthdaysFromCalendar", true);
     mShowAnniversariesFromCal = group.readEntry("AnniversariesFromCalendar", true);
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     mShowMineOnly = group.readEntry("ShowMineOnly", false);
 
     updateView();
@@ -267,3 +267,5 @@ bool ApptSummaryWidget::eventFilter(QObject *obj, QEvent *e)
 
     return KontactInterface::Summary::eventFilter(obj, e);
 }
+
+#include "moc_apptsummarywidget.cpp"
