@@ -23,9 +23,7 @@ ManageShowCollectionProperties::ManageShowCollectionProperties(AkonadiCollection
 {
 }
 
-ManageShowCollectionProperties::~ManageShowCollectionProperties()
-{
-}
+ManageShowCollectionProperties::~ManageShowCollectionProperties() = default;
 
 void ManageShowCollectionProperties::showCollectionProperties()
 {
@@ -81,3 +79,5 @@ void ManageShowCollectionProperties::slotCollectionPropertiesFinished(KJob *job)
         mHashDialogBox.insert(collection.id(), dlg);
     }
 }
+
+#include "moc_manageshowcollectionproperties.cpp"
